@@ -281,7 +281,7 @@ class ready(AcceptPleaseRequests, statemachine.State):
     """
 
     # this must be greater than both the ping timeout (10s) and the sut_verify
-    # timeout (195s).  It should be large, too, to keep load on the imaging server
+    # timeout (30s).  It should be large, too, to keep load on the imaging server
     # to a reasonable level
     TIMEOUT = 600
 
@@ -337,7 +337,7 @@ class pc_power_cycling(PowerCycleMixin, statemachine.State):
         # verify SUT if this device has it; otherwise wait for it to
         # reboot and then ping it
         if self.db.devices.has_sut_agent(self.machine.device_name):
-            self.machine.goto_state(sut_verifying)
+            self.machine.goto_state(pc_sut_rebooting)
         else:
             self.machine.goto_state(pc_rebooting)
 
@@ -360,6 +360,21 @@ class pc_rebooting(statemachine.State):
         self.machine.goto_state(pc_pinging)
 
 
+@DeviceStateMachine.state_class
+class pc_sut_rebooting(statemachine.State):
+    """
+    We have rebooted the device via SUT.  The effect isn't immediate, though, so
+    we give the device a short time to shut itself down.  Without this, it's possible
+    to successfully run a SUT verify *before* the device reboots, which is not what
+    we want!
+    """
+
+    TIMEOUT = 10
+
+    def on_timeout(self):
+        self.machine.goto_state(sut_verifying)
+
+
 @DeviceStateMachine.state_class
 class pc_pinging(statemachine.State):
     """
@@ -731,8 +746,8 @@ class sut_sdcard_verifying(statemachine.State):
     """
 
     PERMANENT_FAILURE_COUNT = 2
-    # this should be greater than the sdcard timeout (30s)
-    TIMEOUT = 60
+    # this should be greater than the sdcard timeout (195s)
+    TIMEOUT = 200
 
     def on_entry(self):
         def sdcard_verified(success):
