@@ -2,7 +2,9 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
+import json
 import threading
+from itertools import izip_longest
 
 class LocksByName(object):
     """A collection of named locks, each individually lockable."""
@@ -24,3 +26,20 @@ class LocksByName(object):
             lock = self._locks_by_name[name]
         lock.release()
 
+def from_json(s):
+    """
+    Converts JSON string 's' to an object but also handles empty/bad values.
+    """
+    try:
+        return json.loads(s)
+    except ValueError:
+        return {}
+
+def mac_with_dashes(mac):
+    """
+    Reformat a 12-digit MAC address to contain
+    a dash between each 2 characters.
+    """
+    # From the itertools docs.
+    return "-".join("%s%s" % i for i in izip_longest(fillvalue=None, *[iter(mac)]*2))
+
